CosmoSpectra
-------------
CosmoSpectra package is meant for Fourier analysis of cosmological simulations.
For full documentation, look [here](https://cosmospectra.readthedocs.io/en/latest/).

PREREQUISITES
-------------
1. [Numpy](http://www.numpy.org/)
2. [Scipy](https://scipy.org/install.html)
3. [Numba](https://numba.pydata.org/)
4. [Astropy](https://www.astropy.org/)

INSTALLATION
------------
One can install a stable version of this package using pip by running the following command::

    pip install cosmospectra

This package is being actively under-development, which involves addition of new modules and bug fixes. In order to use the latest version, one can clone this package.

To install the package in the standard location, run the following in the root directory::

    python setup.py install

In order to install it in a separate directory::

    python setup.py install --home=directory

One can also install the latest version using pip by running the following command::

    pip install git+https://github.com/sambit-giri/cosmospectra.git
